OSDN Git Service

Update comments.
authorkenner <kenner@138bc75d-0d04-0410-961f-82ee72b054a4>
Wed, 25 Jan 1995 19:40:53 +0000 (19:40 +0000)
committerkenner <kenner@138bc75d-0d04-0410-961f-82ee72b054a4>
Wed, 25 Jan 1995 19:40:53 +0000 (19:40 +0000)
git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@8811 138bc75d-0d04-0410-961f-82ee72b054a4

gcc/c-aux-info.c
gcc/cccp.c
gcc/config/convex/convex.md
gcc/config/m68k/m68k.md
gcc/config/m88k/x-dolph
gcc/config/mips/mips.md
gcc/config/ns32k/ns32k.c
gcc/config/sparc/sparc.md
gcc/cse.c
gcc/protoize.c
gcc/sched.c

index 0e7df9b..6d126de 100644 (file)
@@ -1,8 +1,8 @@
 /* Generate information regarding function declarations and definitions based
    on information stored in GCC's tree structure.  This code implements the
    -aux-info option.
-   Copyright (C) 1989, 1991, 1994 Free Software Foundation, Inc.
-   Contributed by Ron Guilmette (rfg@netcom.com).
+   Copyright (C) 1989, 1991, 1994, 1995 Free Software Foundation, Inc.
+   Contributed by Ron Guilmette (rfg@segfault.us.com).
 
 This file is part of GNU CC.
 
@@ -208,7 +208,7 @@ gen_formal_list_for_type (fntype, style)
      to output the "void" verbatim, and that what we do.  In the former case,
      we do our best to give protoize something nice to insert.
 
-     This "something nice" should be something that is still legal (when
+     This "something nice" should be something that is still valid (when
      re-compiled) but something that can clearly indicate to the user that
      more typing information (for the parameter list) should be added (by
      hand) at some convenient moment.
index a819ace..d72c055 100644 (file)
@@ -7521,7 +7521,7 @@ skip_quoted_string (bp, limit, start_line, count_newlines, backslash_newlines_p,
       bp++;
     } else if (c == '\n') {
       if (traditional) {
-       /* Unterminated strings and character constants are 'legal'.  */
+       /* Unterminated strings and character constants are 'valid'.  */
        bp--;   /* Don't consume the newline. */
        if (eofp)
          *eofp = 1;
index 126fadb..4e8f4fa 100644 (file)
@@ -1,5 +1,5 @@
 ;;- Machine description for GNU compiler, Convex Version
-;;  Copyright (C) 1988, 1994 Free Software Foundation, Inc.
+;;  Copyright (C) 1988, 1994, 1995 Free Software Foundation, Inc.
 
 ;; This file is part of GNU CC.
 
 ;; Use
 ;;     ((a >> b) ^ signbit) - signbit
 ;; where signbit is (1 << 63) >> b
-;; Works for 0..63.  Does not work for 64; unfortunate but legal.
+;; Works for 0..63.  Does not work for 64; unfortunate but valid.
 
 (define_expand "ashrdi3"
   [(set (match_operand:DI 0 "register_operand" "")
index 7cf5011..2633183 100644 (file)
 ;;
 ;; The strategy I use here is to use SYMBOL_REF_FLAG to differentiate 
 ;; these two different operands. The macro LEGITIMATE_PIC_OPERAND_P needs
-;; to be changed to recognize function calls symbol_ref operand as a legal 
+;; to be changed to recognize function calls symbol_ref operand as a valid 
 ;; PIC operand (by checking whether SYMBOL_REF_FLAG is set). This will 
 ;; avoid the compiler to load this symbol_ref operand into a register. 
 ;; Remember, the operand "foo@PLTPC" cannot be called via jsr directly 
index 2a28fab..b31a7a9 100644 (file)
@@ -1,5 +1,5 @@
 # Use link editor directives to make NULL pointers point to 
-# illegal addresses.
+# invalid addresses.
 
 EXTRA_PARTS=crtbegin.o crtend.o gcc.ld
 
index 32f02be..cb74328 100644 (file)
@@ -2861,7 +2861,7 @@ move\\t%0,%z4\\n\\
       DONE;
     }
 
-  /* If operands[1] is a constant address illegal for pic, then we need to
+  /* If operands[1] is a constant address invalid for pic, then we need to
      handle it just like LEGITIMIZE_ADDRESS does.  */
   if (flag_pic && pic_address_needs_scratch (operands[1]))
     {
index 9140994..c475e69 100644 (file)
@@ -1,5 +1,5 @@
 /* Subroutines for assembler code output on the NS32000.
-   Copyright (C) 1988, 1994 Free Software Foundation, Inc.
+   Copyright (C) 1988, 1994, 1995 Free Software Foundation, Inc.
 
 This file is part of GNU CC.
 
@@ -202,7 +202,7 @@ gen_indexed_expr (base, index, scale)
 {
   rtx addr;
 
-  /* This generates an illegal addressing mode, if BASE is
+  /* This generates an invalid addressing mode, if BASE is
      fp or sp.  This is handled by PRINT_OPERAND_ADDRESS.  */
   if (GET_CODE (base) != REG && GET_CODE (base) != CONST_INT)
     base = gen_rtx (MEM, SImode, base);
index 66f4488..c8c39c1 100644 (file)
    (set_attr "length" "2")])
 
 ;;; ??? This pattern originally clobbered a scratch register.  However, this
-;;; is illegal, the movdi pattern may not use a temp register because it
+;;; is invalid, the movdi pattern may not use a temp register because it
 ;;; may be called from reload to reload a DImode value.  In that case, we
 ;;; end up with a scratch register that never gets allocated.  To avoid this,
 ;;; we use global register 1 which is never otherwise used by gcc as a temp.
   "smul %1,%2,%R0\;rd %%y,%0"
   [(set_attr "length" "2")])
 
-;; Extra pattern, because sign_extend of a constant isn't legal.
+;; Extra pattern, because sign_extend of a constant isn't valid.
 
 (define_insn "const_mulsidi3"
   [(set (match_operand:DI 0 "register_operand" "=r")
   "umul %1,%2,%R0\;rd %%y,%0"
   [(set_attr "length" "2")])
 
-;; Extra pattern, because sign_extend of a constant isn't legal.
+;; Extra pattern, because sign_extend of a constant isn't valid.
 
 (define_insn "const_umulsidi3"
   [(set (match_operand:DI 0 "register_operand" "=r")
index afb464c..bcec8cd 100644 (file)
--- a/gcc/cse.c
+++ b/gcc/cse.c
@@ -1,5 +1,5 @@
 /* Common subexpression elimination for GNU compiler.
-   Copyright (C) 1987, 88, 89, 92, 93, 1994 Free Software Foundation, Inc.
+   Copyright (C) 1987, 88, 89, 92, 93, 94, 1995 Free Software Foundation, Inc.
 
 This file is part of GNU CC.
 
@@ -6261,7 +6261,7 @@ cse_insn (insn, in_libcall_block)
 
       /* If this is a STRICT_LOW_PART assignment, src_eqv corresponds to the
         value of the INNER register, not the destination.  So it is not
-        a legal substitution for the source.  But save it for later.  */
+        a valid substitution for the source.  But save it for later.  */
       if (GET_CODE (dest) == STRICT_LOW_PART)
        src_eqv_here = 0;
       else
index f4c92f3..823afcd 100644 (file)
@@ -1,5 +1,5 @@
 /* Protoize program - Original version by Ron Guilmette at MCC.
-   Copyright (C) 1989, 1992, 1993, 1994 Free Software Foundation, Inc.
+   Copyright (C) 1989, 1992, 1993, 1994, 1995 Free Software Foundation, Inc.
 
 This file is part of GNU CC.
 
@@ -812,7 +812,7 @@ restore_pointers ()
   repl_write_ptr = saved_repl_write_ptr;
 }
 
/* Return true if the given character is a legal identifier character.  */
 
 static int
 is_id_char (ch)
@@ -3486,7 +3486,7 @@ find_rightmost_formals_list (clean_text_p)
          sure that this is in fact the right paren that we were looking for.
 
          The one we were looking for *must* be followed by either a '{' or
-         by an alphabetic character, while others *cannot* legally be followed
+         by an alphabetic character, while others *cannot* validly be followed
          by such characters.  */
 
       if ((ch == '{') || isalpha (ch))
index 0f08b65..49c37b1 100644 (file)
@@ -1,5 +1,5 @@
 /* Instruction scheduling pass.
-   Copyright (C) 1992, 1993, 1994 Free Software Foundation, Inc.
+   Copyright (C) 1992, 1993, 1994, 1995 Free Software Foundation, Inc.
    Contributed by Michael Tiemann (tiemann@cygnus.com)
    Enhanced by, and currently maintained by, Jim Wilson (wilson@cygnus.com)
 
@@ -3426,7 +3426,7 @@ schedule_block (b, file)
                  {
                    if ((REG_NOTE_KIND (link) == REG_DEAD
                         || REG_NOTE_KIND (link) == REG_UNUSED)
/* Verify that the REG_NOTE has a legal value.  */
                        && GET_CODE (XEXP (link, 0)) == REG)
                      {
                        register int regno = REGNO (XEXP (link, 0));
@@ -3529,7 +3529,7 @@ schedule_block (b, file)
              next = XEXP (link, 1);
              if ((REG_NOTE_KIND (link) == REG_DEAD
                   || REG_NOTE_KIND (link) == REG_UNUSED)
/* Verify that the REG_NOTE has a legal value.  */
                  && GET_CODE (XEXP (link, 0)) == REG)
                {
                  register int regno = REGNO (XEXP (link, 0));
@@ -812,7 +812,7 @@ restore_pointers ()
 }
 
-/* Return true if the given character is a legal identifier character.  */
+/* Return true if the given character is a valid identifier character.  */
 
 static int
@@ -3426,7 +3426,7 @@ schedule_block (b, file)
                    if ((REG_NOTE_KIND (link) == REG_DEAD
                         || REG_NOTE_KIND (link) == REG_UNUSED)
-                       /* Verify that the REG_NOTE has a legal value.  */
+                       /* Verify that the REG_NOTE has a valid value.  */
                        && GET_CODE (XEXP (link, 0)) == REG)
                      {
@@ -3529,7 +3529,7 @@ schedule_block (b, file)
              if ((REG_NOTE_KIND (link) == REG_DEAD
                   || REG_NOTE_KIND (link) == REG_UNUSED)
-                 /* Verify that the REG_NOTE has a legal value.  */
+                 /* Verify that the REG_NOTE has a valid value.  */
                  && GET_CODE (XEXP (link, 0)) == REG)
                {